# SPDX-License-Identifier: MIT
#
{{ ansible_managed | comment }}
{{ "system_role:ad_integration" | comment(prefix="", postfix="") }}
[active-directory]
default-client = {{ ad_integration_client_software }}

[{{ ad_integration_realm }}]
automatic-id-mapping = {{ ad_integration_auto_id_mapping }}
{% if ad_integration_computer_ou %}
computer-ou = {{ ad_integration_computer_ou }}
{% endif %}
